Anonymize: Realistic random data — Recipe 0.14.0 documentation

# Anonymize: Realistic random data

The Anonymize extension lets generate anonymous data that resembles real data.

class `recipe.` `Anonymize`(*args, **kwargs)

  Allows recipes to be anonymized by adding an anonymize property. This flips the anonymize flag on all Ingredients used in the recipe.

  Injects an ingredient.meta._anonymize boolean property on each used ingredient.

  AnonymizeRecipe should occur last

  `add_ingredients`()

    Put the anonymizers in the last position of formatters

  `anonymize`(value)

    Should this recipe be anonymized